@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.3 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowNew.php,v 1.3 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowNew extends SyL_AdmFlow
@@ -100,13 +100,13 @@ class SyL_AdmFlowNew extends SyL_AdmFlow
             // ؿʤ
             if ($data->get('__adm_next')) {
                 // Хǡ¹
-                if ($form->validate()) {
+                if ($adm->validate()) {
                     // ǧ̤
                     $form->setReadOnly(true);
                 }
             } else if ($data->get('__adm_exe')) {
                 // Хǡ¹
-                if ($form->validate()) {
+                if ($adm->validate()) {
                     // Ͽ¹
                     $adm->insert();
                     // λ̤إ쥯
