@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.4 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.5 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/lib/DB/Dao/SyL_DBDaoTable.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperation.php,v 1.4 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperation.php,v 1.5 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperation
@@ -113,6 +113,26 @@ class SyL_AdmOperation
         $this->keys     = $keys;
     }
 
+    /**
+     * 饹Υץѥƥơ֥ȴϢ
+     *
+     * @access public
+     */
+    function loadConfig()
+    {
+        foreach ($this->form->getTableClasses() as $alias => $classname) {
+            $classname = SyL_Loader::convertClass($classname, true);
+            $table =& new $classname();
+            $this->addTable($table, $alias);
+        }
+        $relations = $this->form->getTableRelations();
+        if ($relations) {
+            foreach ($relations as $columns) {
+                $this->addRelation($columns);
+            }
+        }
+    }
+
     /**
      * ơ֥륪֥Ȥ򥻥åȤ
      *
@@ -127,9 +147,9 @@ class SyL_AdmOperation
             $table->addColumn($column);
         }
         if ($alias && is_string($alias)) {
-            // ǥեե饰
+            // ǥեե饰̵
             $table->setDefaultAll(false);
-            // ơ֥̾
+            // ơ֥̾å
             $table->setAliasName($alias);
             $this->tables[$alias] =& $table;
         } else {
@@ -153,26 +173,6 @@ class SyL_AdmOperation
         $this->relation->addJoin($this->tables[$alias1], $this->tables[$alias2], $operator, $columns);
     }
 
-    /**
-     * 饹Υץѥƥơ֥ȴϢ
-     *
-     * @access public
-     */
-    function loadConfig()
-    {
-        foreach ($this->form->getTableClasses() as $alias => $classname) {
-            $classname = SyL_Loader::convertClass($classname, true);
-            $table =& new $classname();
-            $this->addTable($table, $alias);
-        }
-        $relations = $this->form->getTableRelations();
-        if ($relations) {
-            foreach ($relations as $columns) {
-                $this->addRelation($columns);
-            }
-        }
-    }
-
     /**
      * 祭
      *
@@ -275,15 +275,17 @@ class SyL_AdmOperation
         $valid = true;
         $primaries = $this->getPrimary(true);
         foreach ($this->keys as $keys) {
+            $and = false;
             foreach (explode(',', $keys) as $key) {
-                if (substr_count($key, '.') >= 2) {
+                if (substr_count($key, '.') > 1) {
                     list($alias_tmp, $column, $value) = explode('.', $key, 3);
                     if ($alias_tmp == $alias) {
                         if (array_search("{$alias_tmp}.{$column}", $primaries) === false) {
                             $valid = false;
                             break;
                         }
-                        $conditions->addEqual($column, $value, true, false);
+                        $conditions->addEqual($column, $value, true, $and);
+                        $and = true;
                     }
                 } else {
                     $valid = false;
@@ -323,7 +325,27 @@ class SyL_AdmOperation
     }
 
     /**
-     * 祭ѥ᡼
+     * 祭ѥ᡼ƬΤߡ
+     *
+     * @access public
+     * @return array 祭ѥ᡼
+     */
+    function getKey()
+    {
+        $keys = array();
+        if (count($this->keys) > 0) {
+            foreach (explode(',', $this->keys[0]) as $key) {
+                if (substr_count($key, '.') > 1) {
+                    list($alias, $column, $value) = explode('.', $key, 3);
+                    $keys[$column] = $value;
+                }
+            }
+        }
+        return $keys;
+    }
+
+    /**
+     * 祭ѥ᡼ƬΤߡ
      *
      * @access public
      * @return string 祭ѥ᡼
@@ -332,6 +354,17 @@ class SyL_AdmOperation
     {
         return (count($this->keys) > 0) ? $this->keys[0] : '';
     }
+
+    /**
+     * Хǡ¹
+     *
+     * @access public
+     * @return bool Хǡ
+     */
+    function validate()
+    {
+        return $this->form->validate();
+    }
 }
 
 ?>
