@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.6 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.7 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Request.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ContextJs.php,v 1.6 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ContextJs.php,v 1.7 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ContextJs extends SyL_Context
@@ -131,18 +131,36 @@ class SyL_ContextJs extends SyL_Context
      * @access public
      * @return string SCRIPT_NAME
      */
-    function getUrl()
+    function getScriptName()
     {
-        return isset($_SERVER['SCRIPT_NAME']) ? $_SERVER['SCRIPT_NAME'] : null;
+        $request_uri = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';
+        $script_name = isset($_SERVER['SCRIPT_NAME']) ? $_SERVER['SCRIPT_NAME'] : '';
+        if ($request_uri && $script_name) {
+            if (preg_match ('/^' . preg_quote($script_name, '/') . '/', $request_uri)) {
+                return $script_name;
+            } else {
+                // ĥҤ̵б
+                $path_parts = pathinfo($script_name);
+                if (isset($path_parts['extension'])) {
+                    $path_parts['basename'] = basename($script_name, '.' . $path_parts['extension']);
+                }
+                if ($path_parts['dirname'] == '/') {
+                    $path_parts['dirname'] = '';
+                }
+                return $path_parts['dirname'] . '/' . $path_parts['basename'];
+            }
+        } else {
+            return null;
+        }
     }
 
     /**
      * ĶѿꥯURLPHP_SELFˤ
      *
      * @access public
-     * @return string SCRIPT_NAME
+     * @return string PHP_SELF
      */
-    function getUrlContainsPathinfo()
+    function getPhpSelf()
     {
         return isset($_SERVER['PHP_SELF']) ? $_SERVER['PHP_SELF'] : null;
     }
@@ -153,7 +171,7 @@ class SyL_ContextJs extends SyL_Context
      * @access public
      * @return string PATHINFO
      */
-    function getPathinfo()
+    function getPathInfo()
     {
         return isset($_SERVER['PATH_INFO']) ? $_SERVER['PATH_INFO'] : null;
     }
