@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.20 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.21 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.20 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorWeb.php,v 1.21 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorWeb extends SyL_Error
@@ -99,23 +99,22 @@ class SyL_ErrorWeb extends SyL_Error
         }
 
         // 顼ɽȽ
+/*
         $error_View_type = '';
         $view_type = explode(':', SYL_ERROR_FORWARD_TYPE);
         switch (strtolower($view_type[0])) {
-        case 'redirect':
-            $error_View_type = 'Redirect';
-            $template_file   = SYL_ERROR_FORWARD_FILE;
-            break;
+        case 'redirect': $error_View_type = 'Redirect'; break;
         case 'view':
-        case 'layout':
-            $error_View_type = 'Template';
-            $template_file   = SYL_ERROR_FORWARD_FILE;
-            break;
-        default:
-            $error_View_type = 'Default';
-            $template_file   = SYL_INCLUDE_DIR . '/framework/Error/default_error_web.php';
-            break;
+        case 'layout':   $error_View_type = 'Template'; break;
+        default:         $error_View_type = 'Default';  break;
         }
+*/
+        $error_View_type = 'Default';
+        $template_file   = SYL_ERROR_FORWARD_FILE;
+        $view_type       = array();
+
+        SyL_Response::setStatusHeader('500');
+        SyL_Response::setHeader('Content-Type', 'text/html; charset=' . SYL_ENCODE_INTERNAL);
 
         // 顼ɽ
         $func_name = "displayError{$error_View_type}";
@@ -139,8 +138,6 @@ class SyL_ErrorWeb extends SyL_Error
         include_once $template_file;
         $contents = ob_get_clean();
 
-        $content_type = 'text/html; charset=' . SYL_ENCODE_INTERNAL;
-        SyL_Response::setHeader('Content-Type', $content_type);
         $response =& SyL_Response::singleton();
         $response->display($contents);
     }
@@ -154,6 +151,7 @@ class SyL_ErrorWeb extends SyL_Error
      * @param string 顼ȥ졼
      * @param string ӥ塼
      */
+/*
     function displayErrorTemplate($template_file, $_error_message, $_error_lines, $_error_trace, $view_type)
     {
         // ǡ饹
@@ -173,6 +171,7 @@ class SyL_ErrorWeb extends SyL_Error
         $response =& SyL_Response::singleton();
         $response->display($view);
     }
+*/
 
     /**
      * 顼ڡ˥쥯
@@ -183,11 +182,12 @@ class SyL_ErrorWeb extends SyL_Error
      * @param string 顼ȥ졼
      * @param string ӥ塼
      */
+/*
     function displayErrorRedirect($template_file, $_error_message, $_error_lines, $_error_trace, $view_type)
     {
         SyL_Response::redirect($template_file);
     }
-
+*/
 }
 
 ?>
