@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerFile.php,v 1.15 2007/06/05 13:08:24 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerFile.php,v 1.16 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_File.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_LoggerFile.php,v 1.15 2007/06/05 13:08:24 seasonstream Exp $
+ * @version   CVS: $Id: SyL_LoggerFile.php,v 1.16 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_LoggerFile extends SyL_Logger
@@ -86,7 +86,7 @@ class SyL_LoggerFile extends SyL_Logger
     function log($level, $message)
     {
         if ($level != '') {
-            $message = sprintf('%s [%s] [%s] %s "%s %s" %s', date($this->datetime_format), SYL_ENV_TYPE, $level, $this->remote_addr, $this->request_method, $this->request_uri, rtrim($message));
+            $message = sprintf('%s [%s] [%s] %s', date($this->datetime_format), SYL_ENV_TYPE, $level, rtrim($message));
         }
         if ($this->immediate || ($level == '')) {
             $this->appender->write($message . $this->eol);
