@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.17 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.18 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterParameter.php,v 1.17 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterParameter.php,v 1.18 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterParameter extends SyL_Router
@@ -74,11 +74,11 @@ class SyL_RouterParameter extends SyL_Router
         switch (count($pathinfo)) {
         case 0:
             $this->action_method = '';
-            $this->action_file   = '/' . $this->action_file_default;
+            $this->action_file   = '/' . ucfirst($this->action_file_default);
             break;
         case 1:
             $this->action_method = array_pop($pathinfo);
-            $this->action_file   = '/' . $this->action_file_default;
+            $this->action_file   = '/' . ucfirst($this->action_file_default);
             break;
         default:
             $this->action_method =  array_pop($pathinfo);
