@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.19 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.20 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.19 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.20 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo extends SyL_Router
@@ -65,10 +65,10 @@ class SyL_RouterPathinfo extends SyL_Router
 
         if ($pathinfo == '') {
             $this->action_method = '';
-            $this->action_file   = '/' . $this->action_file_default;
+            $this->action_file   = '/' . ucfirst($this->action_file_default);
         } else if (substr($pathinfo, -1) == '/') {
             $this->action_method = '';
-            $this->action_file   = $pathinfo . $this->action_file_default;
+            $this->action_file   = implode('/', array_map('ucfirst', explode('/', $pathinfo))) . $this->action_file_default;
         } else {
             // ĥȽ
             if ($this->url_ext && !preg_match('/^(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo)) {
