@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Action.php,v 1.2 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Action.php,v 1.3 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Action.php,v 1.2 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Action.php,v 1.3 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Action
@@ -89,7 +89,7 @@ class SyL_Action
             $dsns[$dsn]->setCallbackSqlLog(array(__CLASS__, 'addLogDBSql'));
             $dsns[$dsn]->setCallbackErrorLog(array(__CLASS__, 'addLogDBError'));
             //register_shutdown_function(array(&$dsns[$dsn], 'closeConnection'));
-            SyL_Loggers::info("[Action] DB connection start");
+            SyL_Loggers::info("[Action] getDB for Action");
         }
         return $dsns[$dsn];
     }
@@ -144,12 +144,10 @@ class SyL_Action
      * @access protected
      * @return object 桼֥
      */
-    function getUser()
+    function &getUser()
     {
-        // ǧڥ֥ȼ
-        if (!class_exists('SyL_Auth')) {
-            trigger_error("[SyL error] SyL_Auth object not declared. use `SyL_FilterAuth' filter ?", E_USER_ERROR);
-        }
+        // AUTH饹󥯥롼
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_Auth.php';
         $auth =& SyL_Auth::singleton();
         return $auth->getUser();
     }
@@ -162,10 +160,8 @@ class SyL_Action
      */
     function doLogout()
     {
-        // ǧڥ֥ȼ
-        if (!class_exists('SyL_Auth')) {
-            trigger_error("[SyL error] SyL_Auth object not declared. use `SyL_FilterAuth' filter ?", E_USER_ERROR);
-        }
+        // AUTH饹󥯥롼
+        include_once SYL_INCLUDE_DIR . '/framework/SyL_Auth.php';
         $auth =& SyL_Auth::singleton();
         $auth->doLogout();
     }
