@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.6 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.7 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_Form.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ActionForm.php,v 1.6 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ActionForm.php,v 1.7 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ActionForm extends SyL_Form
@@ -305,6 +305,8 @@ class SyL_ActionForm extends SyL_Form
             $this->elements_config_etc[$name]['cols'] = isset($values['cols']) ? $values['cols'] : '1';
             $this->elements_config_etc[$name]['read_only_new'] = isset($values['read_only_new']) ? $values['read_only_new'] : false;
             $this->elements_config_etc[$name]['read_only_upd'] = isset($values['read_only_upd']) ? $values['read_only_upd'] : false;
+            $this->elements_config_etc[$name]['default_new']   = isset($values['default_new'])   ? $values['default_new']   : false;
+            $this->elements_config_etc[$name]['default_upd']   = isset($values['default_upd'])   ? $values['default_upd']   : false;
 
             // Ƚ
             $sort = (isset($values['sort_detail']) && $values['sort_detail']) ? $values['sort_detail'] : $i++;
@@ -394,6 +396,7 @@ class SyL_ActionForm extends SyL_Form
           'read_only' => true,
           'cols'      => '1'
         );
+
         foreach (array_keys($this->results['elements']) as $name) {
             // ɽѹ
             $end_space = false;
@@ -489,6 +492,30 @@ class SyL_ActionForm extends SyL_Form
             return null;
         }
     }
+
+    /**
+     * ǥեͤ
+     *
+     * @access public
+     * @return array ǥե
+     */
+    function getDefaults()
+    {
+        $default_name = '';
+        switch ($this->type) {
+        case 'new': $default_name = 'default_new'; break;
+        case 'upd': $default_name = 'default_upd'; break;
+        default:    return array();
+        }
+
+        $defaults = array();
+        foreach ($this->elements_config_etc as $name => $values) {
+            if (isset($values[$default_name]) && ($values[$default_name] !== false)) {
+                $defaults[$name] = $values[$default_name];
+            }
+        }
+        return $defaults;
+    }
 }
 
 ?>
