@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.7 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.8 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_User.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Auth.php,v 1.7 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Auth.php,v 1.8 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Auth
@@ -95,7 +95,7 @@ class SyL_Auth
         }
 
         if (!isset($singleton[$type])) {
-            SyL_Loggers::info("[Auth] Create Auth Type: {$type}");
+            SyL_Loggers::info("[Auth] Initialize Auth Type: {$type}");
 
             $classname = 'SyL_Auth' . ucfirst($type);
             include_once SYL_INCLUDE_DIR . "/framework/Auth/{$classname}.php";
@@ -108,7 +108,7 @@ class SyL_Auth
             $singleton[$type]->setSessionObject($request->getSessionObject());
             // å̾å
             $singleton[$type]->setSessionName($classname);
-            $user = $singleton[$type]->getUser();
+            $user =& $singleton[$type]->getUser();
             // 桼֥ȤƤʤޤϥ󤷤Ƥʤк
             if (!$user) {
                 $singleton[$type]->setUser(new $classname());
@@ -145,9 +145,10 @@ class SyL_Auth
      * @access public
      * @return object 桼֥
      */
-    function getUser()
+    function &getUser()
     {
-        return $this->session->get($this->session_name);
+        $user = $this->session->get($this->session_name);
+        return $user;
     }
 
     /**
@@ -156,7 +157,7 @@ class SyL_Auth
      * @access public
      * @param object 桼֥
      */
-    function setUser($user)
+    function setUser(&$user)
     {
         return $this->session->set($this->session_name, $user);
     }
@@ -169,7 +170,7 @@ class SyL_Auth
      */
     function getLoginParameterName()
     {
-        $user = $this->getUser();
+        $user =& $this->getUser();
         return array($user->getUserIdParamaterName(), $user->getPasswordParamaterName());
     }
 
@@ -183,12 +184,29 @@ class SyL_Auth
     {
         $session_error_url = call_user_func(array(__CLASS__, 'getAuthSessionErrorUrl'));
         if ($_SERVER['PHP_SELF'] == $session_error_url) {
+            SyL_Loggers::info("[Auth] Auth Area: false. (because SYL_AUTH_SESSION_ERROR_URL)");
             return false;
         }
 
-        $request_uri = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '/';
-        $auth_url    = call_user_func(array(__CLASS__, 'getAuthUrl'));
-        return (bool)preg_match('/^' . preg_quote($auth_url, '/') . '/', $request_uri);
+        $request_uri = '';
+        if (isset($_SERVER['REQUEST_URI'])) {
+            $request_uri = $_SERVER['REQUEST_URI'];
+        } else {
+            trigger_error('[SyL error] $_SERVER["REQUEST_URI"] not exist', E_USER_ERROR);
+        }
+
+        $auth_url = call_user_func(array(__CLASS__, 'getAuthUrl'));
+
+        SyL_Loggers::debug("[Auth] REQUEST_URI: $request_uri");
+        SyL_Loggers::debug("[Auth] AUTH_URL: $auth_url");
+
+        if (preg_match('/^' . preg_quote($auth_url, '/') . '/', $request_uri)) {
+            SyL_Loggers::info("[Auth] Auth Area: true");
+            return true;
+        } else {
+            SyL_Loggers::info("[Auth] Auth Area: false");
+            return false;
+        }
     }
 
     /**
@@ -200,7 +218,7 @@ class SyL_Auth
     function isLoginAction()
     {
         list($id, $passwd) = $this->getLoginParameterName();
-            SyL_Loggers::info("[Auth] a: $id, $passwd");
+        SyL_Loggers::debug("[Auth] login parameter ID: $id PASSWD: $passwd");
         if (($_SERVER['REQUEST_METHOD'] == 'POST') && isset($_POST[$id]) && isset($_POST[$passwd])) {
             SyL_Loggers::info("[Auth] Login Action: true");
             return true;
@@ -234,8 +252,7 @@ class SyL_Auth
     function isLoginPassword($client_username, $client_password, $server_password)
     {
         if (!$this->isLoginAction()) {
-            SyL_Loggers::warn("[Auth] Login Failed. No Login Action. (class: " . get_class($this) . " user: {$client_username} hash: " . SYL_AUTH_PASSWORD_HASH . ")");
-            return false;
+            SyL_Loggers::notice("[Auth] Login Failed. No Login Action. (class: " . get_class($this) . " user: {$client_username} hash: " . SYL_AUTH_PASSWORD_HASH . ")");
         }
         if (($client_username === null) || ($client_username === '')) {
             SyL_Loggers::warn("[Auth] Login Failed. Empty UserName. (class: " . get_class($this) . " user: {$client_username} hash: " . SYL_AUTH_PASSWORD_HASH . ")");
@@ -297,19 +314,22 @@ class SyL_Auth
         }
 
         // 桼֥ȼ
-        $user = $this->getUser();
-        if ($server_password === $client_password) {
+        $user =& $this->getUser();
+        if (($server_password !== '')   &&
+            ($server_password !== null) &&
+            ($server_password === $client_password)) {
             SyL_Loggers::info("[Auth] Login Success. (class: " . get_class($this) . " user: {$client_username})");
             // 桼IDå
             $user->setUserId($client_username);
             // OK٥
-            $user->triggerLoginSuccess();
+            $user->triggerLoginSuccess($client_username);
             $this->setUser($user);
             return true;
         } else {
             SyL_Loggers::warn("[Auth] Login Failed. Invalid Password. (class: " . get_class($this) . " user: {$client_username})");
+            SyL_Loggers::warn("aaaa: " . get_class($user));
             // 󥨥顼٥
-            $user->triggerLoginFailed();
+            $user->triggerLoginFailed($client_username);
             $this->setUser($user);
             return false;
         }
@@ -323,7 +343,7 @@ class SyL_Auth
      */
     function isLogin()
     {
-        $user = $this->getUser();
+        $user =& $this->getUser();
         return $user->isLogin();
     }
 
@@ -334,7 +354,7 @@ class SyL_Auth
      */
     function deleteLogin()
     {
-        $this->setUser(null);
+        $this->setUser($user=null);
     }
 
     /**
@@ -345,11 +365,11 @@ class SyL_Auth
      */
     function doLogout()
     {
-        $user = $this->getUser();
+        $user =& $this->getUser();
         $client_username = $user->getUserId();
         SyL_Loggers::info("[Auth] Logout Success. (class: " . get_class($this) . " user: {$client_username})");
         // ȥ٥
-        $user->triggerLogout();
+        $user->triggerLogout($client_username);
         $this->deleteLogin();
         session_destroy();
     }
