@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.10 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.11 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.10 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.11 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
@@ -247,7 +247,7 @@ class SyL_Context
         }
 
         // ǥХå - ƥץ졼Ȥξ
-        SyL_Loggers::debug("[Context] Template info dir: {$template_dir} file: {$template_file}");
+        SyL_Loggers::debug("[Context] Template dir: {$template_dir} file: {$template_file}");
 
         // ƥץ졼ȥե¸ߥå
         if (!is_file($template_dir . $template_file)) {
