@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.28 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.29 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -69,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.28 2007/09/02 14:40:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.29 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -310,8 +310,22 @@ class SyL_Controller
      */
     function initStream()
     {
+        $config_files = array();
+        // Х륳ݡͥե
+        $config_files['components'][] = SYL_PROJECT_CONFIG_DIR . "/{$this->components_file_name}";
         // ٥ȼ¹
-        $this->raiseEvent('initStream');
+        $this->raiseEvent('initStream', $config_files);
+
+        // ꥯȽ
+        if (SYL_ENV_TYPE == 'cmd') {
+            $script_file = isset($_SERVER['SCRIPT_FILENAME']) ? $_SERVER['SCRIPT_FILENAME'] : '';
+            SyL_Loggers::info("[Controller] cmd start: {$script_file}");
+        } else {
+            $method = isset($_SERVER['REQUEST_METHOD']) ? $_SERVER['REQUEST_METHOD'] : '';
+            $addr   = isset($_SERVER['REMOTE_ADDR'])    ? $_SERVER['REMOTE_ADDR']    : '';
+            $uri    = isset($_SERVER['REQUEST_URI'])    ? $_SERVER['REQUEST_URI']    : '';
+            SyL_Loggers::info("[Controller] request start: \"{$method}: {$uri}\" - {$addr}");
+        }
     }
 
     /**
@@ -321,8 +335,20 @@ class SyL_Controller
      */
     function loadStream()
     {
+        $config_files = array();
+        // ץꥱե륿ե
+        $filter = SYL_APP_CONFIG_DIR . "/{$this->filter_file_name}";
+        if (file_exists($filter)) {
+            $config_files['filters'][] = $filter;
+        }
+        // Хե륿ե
+        $filter = SYL_PROJECT_CONFIG_DIR . "/{$this->filter_file_name}";
+        if (file_exists($filter)) {
+            $config_files['filters'][] = $filter;
+        }
+
         // ٥ȼ¹
-        $this->raiseEvent('loadStream');
+        $this->raiseEvent('loadStream', $config_files);
     }
 
     /**
@@ -332,8 +358,12 @@ class SyL_Controller
      */
     function executeStream()
     {
+        $config_files = array();
+        // ե
+        $config_files['actions'][] = SYL_APP_CONFIG_DIR . "/{$this->action_file_name}";
+
         // ٥ȼ¹
-        $this->raiseEvent('executeStream');
+        $this->raiseEvent('executeStream', $config_files);
     }
 
     /**
