@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.5 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.6 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Data.php,v 1.5 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Data.php,v 1.6 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Data extends SyL_UtilProperty
@@ -187,6 +187,22 @@ class SyL_Data extends SyL_UtilProperty
         return $values;
     }
 
+    /**
+     * ץѥƥγǧ
+     * 
+     * @access public
+     * @param string ץѥƥ̾
+     * @return bool true: ץѥƥꡢfalse: ץѥƥ̵
+     */
+    function is($name)
+    {
+        if (parent::is($name)) {
+            return true;
+        } else {
+            return isset($this->input_parameters[$name]);
+        }
+    }
+
     /**
      * ϥѥ᡼򥻥å
      * 
