@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.16 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.17 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,18 +44,11 @@ require_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilProperty.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Request.php,v 1.16 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Request.php,v 1.17 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Request
 {
-    /**
-     * NGXgp[^IuWFNg
-     * 
-     * @access private
-     * @var object
-     */
-    var $parameter = null;
     /**
      * ZbVIuWFNg
      * 
@@ -108,17 +101,6 @@ class SyL_Request
         return $singleton;
     }
 
-    /**
-     * NGXgp[^IuWFNg쐬
-     *
-     * @access private
-     */
-     function createParameter()
-     {
-         include_once SYL_INCLUDE_DIR . "/framework/Request/SyL_RequestParameter.php";
-         $this->parameter =& new SyL_RequestParameter();
-     }
-
     /**
      * ZbVIuWFNg쐬
      *
@@ -159,50 +141,6 @@ class SyL_Request
          $this->files =& new SyL_RequestFile();
      }
 
-    /**
-     * p[^Zbg
-     * 
-     * @access public
-     * @param string p[^
-     * @param string p[^l
-     */
-    function setParameter($name, $value)
-    {
-        if ($this->parameter === null) {
-            $this->createParameter();
-        }
-        $this->parameter->set($name, $value);
-    }
-
-    /**
-     * NGXgl擾
-     *
-     * @access public
-     * @param string p[^
-     * @return mixed p[^l
-     */
-    function getParameter($name)
-    {
-        if ($this->parameter === null) {
-            $this->createParameter();
-        }
-        return $this->parameter->get($name);
-    }
-
-    /**
-     * NGXgIuWFNg擾
-     *
-     * @access public
-     * @return array p[^l
-     */
-    function &getParameterObject()
-    {
-        if ($this->parameter === null) {
-            $this->createParameter();
-        }
-        return $this->parameter;
-    }
-
     /**
      * ZbVlZbg
      * 
