@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.23 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.24 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.23 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.24 2007/09/02 14:40:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -118,16 +118,6 @@ class SyL_View
             // Nullӥ塼
             $classname = 'SyL_ViewNull';
             $classfile = SYL_INCLUDE_DIR . "/framework/View/{$classname}.php";
-        } else if ($type == 'customize') {
-            $classname = $context->getCustomizedViewClass();
-            $classfile = $context->getCustomizedViewFile();
-            if (!is_file($classfile)) {
-                $classfile1 = SYL_PROJECT_LIB_DIR . "/{$classfile}";
-                if (!is_file($classfile1)) {
-                    trigger_error("[SyL error] Customised View file not found ({$classfile} or {$classfile1})", E_USER_ERROR);
-                }
-                $classfile = $classfile1;
-            }
         } else {
             $classname = 'SyL_View' . implode('', array_map('ucfirst', explode('.', $type)));
             $classfile = SYL_INCLUDE_DIR . "/framework/View/{$classname}.php";
