@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.4 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.5 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.4 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDaoTable.php,v 1.5 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDaoTable
@@ -72,6 +72,20 @@ class SyL_DBDaoTable
      * @var array
      */
     var $primary = array();
+    /**
+     * ե
+     * 
+     * @access protected
+     * @var array
+     */
+    var $uniques = array();
+    /**
+     * 
+     * 
+     * @access protected
+     * @var array
+     */
+    var $foreigns = array();
     /**
      * 
      *
@@ -119,9 +133,16 @@ class SyL_DBDaoTable
      * 󥹥ȥ饯
      *
      * @access public
+     * @param string ơ֥̾
      */
-    function SyL_DBDaoTable()
+    function SyL_DBDaoTable($table='', $columns=array())
     {
+        if ($this->table == '') {
+            $this->table = $table;
+        }
+        if (count($this->columns) == 0) {
+            $this->columns = $columns;
+        }
         // ̾ʸѴ
         $this->primary = array_map('strtoupper', $this->primary);
         $this->columns = array_change_key_case($this->columns, CASE_UPPER);
@@ -133,17 +154,17 @@ class SyL_DBDaoTable
      * @access public
      * @param string ̾
      * @param mixed 
-     * @param array SQLؿ̾
+     * @param array SQLؿ
      */
-    function addColumn($name, $value=null, $function=array())
+    function addColumn($name, $value=null, $function=null)
     {
         // ʸ
         $name = strtoupper($name);
         if (isset($this->columns[$name])) {
-            $this->data_columns[$name] = $value;
-            if (is_array($function) && (count($function) > 0)) {
+            if (is_array($function)) {
                 $this->data_functions[$name] = $function;
             }
+            $this->data_columns[$name] = $value;
         } else {
             trigger_error("[SyL error] Column name not found in " . get_class($this) . " class ({$name})", E_USER_ERROR);
         }
@@ -223,16 +244,71 @@ class SyL_DBDaoTable
      * 祭
      *
      * @access public
+     * @param bool ̾ɲåե饰
      * @return array 祭
      */
     function getPrimary($alias_flag=true)
     {
-        $alias = $this->getAliasName();
-        $primary = array();
-        foreach ($this->primary as $tmp) {
-            $primary[] = ($alias_flag) ? "{$alias}.{$tmp}" : $tmp;
+        if ($alias_flag) {
+            $alias = $this->getAliasName();
+            $primary = array();
+            foreach ($this->primary as $column) {
+                $primary[] = "{$alias}.{$column}";
+            }
+            return $primary;
+        } else {
+            return $this->primary;
+        }
+    }
+
+    /**
+     * ե
+     *
+     * @access public
+     * @param bool ̾ɲåե饰
+     * @return array ե
+     */
+    function getUniques($alias_flag=true)
+    {
+        if ($alias_flag) {
+            $alias = $this->getAliasName();
+            $uniques = array();
+            foreach ($this->uniques as $unique) {
+                $tmp = array();
+                foreach ($unique as $column) {
+                    $tmp[] = "{$alias}.{$column}";
+                }
+                $uniques[] = $tmp;
+            }
+            return $uniques;
+        } else {
+            return $this->uniques;
+        }
+    }
+
+    /**
+     * 
+     *
+     * @access public
+     * @param bool ̾ɲåե饰
+     * @return array 
+     */
+    function getForeigns($alias_flag=true)
+    {
+        if ($alias_flag) {
+            $alias = $this->getAliasName();
+            $foreigns = array();
+            foreach ($this->foreigns as $name => $foreign) {
+                $tmp = array();
+                foreach ($foreign as $column1 => $column2) {
+                    $tmp["{$alias}.{$column1}"] = $column2;
+                }
+                $foreigns[$name] = $tmp;
+            }
+            return $foreigns;
+        } else {
+            return $this->foreigns;
         }
-        return $primary;
     }
 
     /**
@@ -471,15 +547,21 @@ class SyL_DBDaoTable
      */
     function getDataColumns($is_alias=false)
     {
-        if ($is_alias && $this->alias) {
-            $columns = array();
-            foreach ($this->data_columns as $name => $value) {
+        $columns = array();
+        foreach ($this->data_columns as $name => $value) {
+            if (isset($this->data_functions[$name])) {
+                $funcs    = $this->data_functions[$name];
+                $funcname = array_shift($funcs);
+                $func     = implode(',', array_map(array(&$conn, 'quote'), $funcs));
+                $value    = "{$funcname}({$func})";
+            }
+            if ($is_alias && $this->alias) {
                 $columns[$this->getAliasName() . '.' . $name] = $value;
+            } else {
+                $columns[$name] = $value;
             }
-            return $columns;
-        } else {
-            return $this->data_columns;
         }
+        return $columns;
     }
 
     /**
