@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSchemaMysql.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSchemaMysql.php,v 1.3 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSchemaMysql.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSchemaMysql.php,v 1.3 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBSchemaMysql extends SyL_DBSchema
@@ -87,6 +87,101 @@ class SyL_DBSchemaMysql extends SyL_DBSchema
         return $result;
     }
 
+    /**
+     * ꤷơ֥μ祭
+     *
+     * @access public
+     * @param string ơ֥̾
+     * @return array 祭
+     */
+    function getPrimary($tablename)
+    {
+        $result = array();
+        $sql = "SHOW COLUMNS FROM {$tablename}";
+        foreach ($this->conn->query($sql) as $column) {
+            if ($column['KEY'] == 'PRI') {
+                $result[] = $column['FIELD'];
+            }
+        }
+        return $result;
+    }
+
+    /**
+     * ꤷơ֥ΰե
+     *
+     * @access public
+     * @param string ơ֥̾
+     * @return array ե
+     */
+    function getUniques($tablename)
+    {
+        $result = array();
+        $sql = "SHOW CREATE TABLE {$tablename}";
+        $create_table = $this->conn->query($sql);
+        if (count($create_table) == 0) {
+            trigger_error("[SyL error] table not found ($tablename)", E_USER_ERROR);
+        }
+
+        $reg = '/UNIQUE KEY `[^`]+` \(([^\)]+)\)/';
+        if (preg_match_all($reg, $create_table[0]['CREATE TABLE'], $matches, PREG_SET_ORDER)) {
+            foreach ($matches as $match) {
+                $tmps = array();
+                foreach (explode(',', $match[1]) as $tmp) {
+                    if (preg_match('/^`(.+)`$/', trim($tmp), $unique)) {
+                        $tmps[] = $unique[1];
+                    }
+                }
+                if (count($tmps) > 0) {
+                    $result[] = $tmps;
+                }
+            }
+        }
+        return $result;
+    }
+
+    /**
+     * ꤷơ֥γ
+     *
+     * @access public
+     * @param string ơ֥̾
+     * @return array 
+     */
+    function getForeigns($tablename)
+    {
+        $result = array();
+        $sql = "SHOW CREATE TABLE {$tablename}";
+        $create_table = $this->conn->query($sql);
+        if (count($create_table) == 0) {
+            trigger_error("[SyL error] table not found ($tablename)", E_USER_ERROR);
+        }
+
+        $reg = '/FOREIGN KEY \(([^\)]+)\) REFERENCES `(.+)` \(([^\)]+)\)/';
+        if (preg_match_all($reg, $create_table[0]['CREATE TABLE'], $matches, PREG_SET_ORDER)) {
+            foreach ($matches as $match) {
+                $columns  = array();
+                $fcolumns = array();
+                foreach (explode(',', $match[1]) as $tmp) {
+                    if (preg_match('/^`(.+)`$/', trim($tmp), $foreign)) {
+                        $columns[] = $foreign[1];
+                    }
+                }
+                foreach (explode(',', $match[3]) as $tmp) {
+                    if (preg_match('/^`(.+)`$/', trim($tmp), $foreign)) {
+                        $fcolumns[] = $foreign[1];
+                    }
+                }
+                if ((count($columns) > 0) && (count($columns) == count($fcolumns))) {
+                    $tmps = array();
+                    foreach (array_map(null, $columns, $fcolumns) as $tmp) {
+                        $tmps[$tmp[0]] = $tmp[1];
+                    }
+                    $result[] = $tmps;
+                }
+            }
+        }
+        return $result;
+    }
+
     /**
      * ꤷơ֥Υ
      *
@@ -97,7 +192,7 @@ class SyL_DBSchemaMysql extends SyL_DBSchema
     function getColumns($tablename)
     {
         $result = array();
-        $sql = "show columns from {$tablename}";
+        $sql = "SHOW COLUMNS FROM {$tablename}";
         foreach ($this->conn->query($sql) as $column) {
             list($type, $min, $max) = $this->getFormat($column['TYPE']);
             $result[$column['FIELD']] = array(
