@@ -35,7 +35,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.5 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.6 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -56,7 +56,7 @@ require_once 'SyL_DBSqlTableRelations.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDao.php,v 1.5 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDao.php,v 1.6 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDao
@@ -259,7 +259,11 @@ class SyL_DBDao
 
         $sql  = "";
         $sql .= "SELECT ";
+        if (count($selects) > 0) {
         $sql .=   implode(', ', $selects) . " ";
+        } else {
+        $sql .=   "* ";
+        }
         $sql .= "FROM ";
         $sql .=   $from . " ";
         if ($where) {
@@ -380,6 +384,114 @@ class SyL_DBDao
         return $result;
     }
 
+    /**
+     * 祭¸ߥå
+     *
+     * @access public
+     * @param object ơ֥륪֥
+     * @param array 祭ǡ
+     * @return bool true: 祭¸ߤ, false: 祭¸ߤʤ
+     */
+    function hasPrimary($table, $datas)
+    {
+        // 索֥Ⱥ
+        $conditions = $this->createCondition();
+        foreach ($table->getPrimary(false) as $tmp) {
+            if (isset($datas[$tmp])) {
+                $conditions->addEqual($tmp, $datas[$tmp]);
+            }
+        }
+        if (count($conditions->gets()) == 0) {
+            // 祭Ĥʤ
+            return false;
+        }
+        // Ȳ
+        $table_tmp = version_compare(PHP_VERSION, '5.0.0', '>=')
+                   ? unserialize(serialize($table))
+                   : $table;
+        // 索֥ȥå
+        $table_tmp->setConditions($conditions);
+        // 祭¸Ƚ
+        return (count($this->select($table_tmp)) > 0);
+    }
+
+    /**
+     * ե¸ߥå
+     *
+     * @access public
+     * @param object ơ֥륪֥
+     * @param array եǡ
+     * @return bool true: ե¸ߤ, false: ե¸ߤʤ
+     */
+    function hasUnique($table, $datas)
+    {
+        foreach ($table->getUniques(false) as $uniques) {
+            // 索֥Ⱥ
+            $conditions = $this->createCondition();
+            foreach ($uniques as $unique) {
+                if (isset($datas[$unique])) {
+                    if ($datas[$unique] !== '') {
+                        $conditions->addEqual($unique, $datas[$unique]);
+                    } else {
+                        //  = null ϡå
+                        continue 2;
+                    }
+                }
+            }
+            if (count($conditions->gets()) > 0) {
+                // Ȳ
+                $table_tmp = version_compare(PHP_VERSION, '5.0.0', '>=')
+                           ? unserialize(serialize($table))
+                           : $table;
+                // ե¸ߤ
+                $table_tmp->setConditions($conditions);
+                // ե¸Ƚ
+                if (count($this->select($table_tmp)) > 0) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    }
+
+    /**
+     * ¸ߥå
+     *
+     * @access public
+     * @param object ơ֥륪֥
+     * @param array ǡ
+     * @param string оݥơ֥̾
+     * @return bool true: ¸ߤ, false: ¸ߤʤ
+     */
+    function hasForeign($table, $datas, &$ftabble)
+    {
+        foreach ($table->getForeigns(false) as $ftabble => $foreigns) {
+            // 索֥Ⱥ
+            $conditions = $this->createCondition();
+            foreach ($foreigns as $column1 => $column2) {
+                if (isset($datas[$column1])) {
+                    if ($datas[$column1] !== '') {
+                        $conditions->addEqual($column2, $datas[$column1]);
+                    } else {
+                        //  = null ϡå
+                        continue 2;
+                    }
+                }
+            }
+
+            if (count($conditions->gets()) > 0) {
+                // ¸ߤ
+                $table_tmp = new SyL_DBDaoTable($ftabble);
+                $table_tmp->setConditions($conditions);
+                // ¸Ƚ
+                if (count($this->select($table_tmp)) > 0) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    }
+
     /**
      * 顼Ƚꤹ
      *
