@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSchema.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSchema.php,v 1.3 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSchema.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSchema.php,v 1.3 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBSchema
@@ -83,7 +83,7 @@ class SyL_DBSchema
             $type = 'Pgsql';
             break;
         default:
-            trigger_error("[SyL error] Unsupported DB type ({$type})", E_USER_ERROR);
+            trigger_error("[SyL error] Not supported DB type schema ({$type})", E_USER_ERROR);
         }
         
         $classname = "SyL_DBSchema{$type}";
@@ -102,6 +102,39 @@ class SyL_DBSchema
     {
     }
 
+    /**
+     * ꤷơ֥μ祭
+     *
+     * @access public
+     * @param string ơ֥̾
+     * @return array 祭
+     */
+    function getPrimary($tablename)
+    {
+    }
+
+    /**
+     * ꤷơ֥ΰե
+     *
+     * @access public
+     * @param string ơ֥̾
+     * @return array ե
+     */
+    function getUniques($tablename)
+    {
+    }
+
+    /**
+     * ꤷơ֥γ
+     *
+     * @access public
+     * @param string ơ֥̾
+     * @return array 
+     */
+    function getForeigns($tablename)
+    {
+    }
+
     /**
      * ꤷơ֥Υ
      *
