@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSqlTableConditions.php,v 1.4 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSqlTableConditions.php,v 1.5 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBSqlTableConditions.php,v 1.4 2007/08/12 05:59:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBSqlTableConditions.php,v 1.5 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBSqlTableConditions
@@ -91,8 +91,8 @@ class SyL_DBSqlTableConditions
     function getWhere(&$conn)
     {
         $wheres = array();
-        $first  = true;
-        $or     = false;
+        $cond   = '';
+
         foreach ($this->wheres as $where) {
             if ($this->alias) {
                 // ̾å
@@ -113,32 +113,47 @@ class SyL_DBSqlTableConditions
             default:
                 $wheres[] = "{$where[0]} {$where[2]} " . $conn->quote($where[1]) . " ";
             }
-            if ($first) {
-                $first = false;
-            } else {
-                $max = count($wheres) - 1;
-                if ($where[3] == 'OR') {
-                    if (!$or) {
-                        $wheres[$max-1] = '(' . $wheres[$max-1];
-                        $or = true;
-                    }
+
+            $max = count($wheres) - 1;
+            switch ($cond) {
+            case 'AND':
+                if ($where[3] != 'AND') {
+                    $wheres[$max-1] .= ') ';
+                    $wheres[$max] = ' ' . $where[3] . ' (' . $wheres[$max];
                 } else {
-                    if ($or) {
-                        $wheres[$max-1] = $wheres[$max-1] . ')';
-                        $or = false;
-                    }
+                    $wheres[$max] = ' ' . $where[3] . ' ' . $wheres[$max];
                 }
-                $wheres[$max] = ' ' . $where[3] . ' ' . $wheres[$max];
+                $cond = 'AND';
+                break;
+            case 'OR':
+                if ($where[3] != 'OR') {
+                    $max = count($wheres) - 1;
+                    $wheres[$max-1] .= ') ';
+                    $wheres[$max] = ' ' . $where[3] . ' (' . $wheres[$max];
+                } else {
+                    $wheres[$max] = ' ' . $where[3] . ' ' . $wheres[$max];
+                }
+                $cond = 'OR';
+                break;
+            default:
+                // AND
+                $cond = 'AND';
             }
         }
 
-        if ($or) {
-            return implode('', $wheres) . ') ';
+        if (count($wheres) > 0) {
+            return ' (' . implode('', $wheres) . ') ';
         } else {
-            return implode('', $wheres);
+            return '';
         }
     }
 
+/*
+  (AAA AND BBB) OR (CCC AND DDD)
+  (AAA OR BBB) AND (CCC OR DDD)
+
+*/
+
     /**
      * whereӡ
      *
