@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.20 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.21 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'DB/SyL_DBSchema.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.20 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.21 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -927,15 +927,14 @@ class SyL_DB
     }
 
     /**
-     * ³ƤDBΥơ֥
+     * ޼֥Ȥ
      *
      * @access public
-     * @return array ơ֥
+     * @return object ޼֥
      */
-    function getTables()
+    function &getSchema()
     {
-        $schema =& SyL_DBSchema::factory($this);
-        return $schema->getTables();
+        return SyL_DBSchema::factory($this);
     }
 
     /**
