@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.1 2007/08/27 14:29:53 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.2 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ SyL_Loader::lib('File');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: Index.php,v 1.1 2007/08/27 14:29:53 seasonstream Exp $
+ * @version   CVS: $Id: Index.php,v 1.2 2007/09/29 09:10:39 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class Index extends AppAction
@@ -318,36 +318,29 @@ class Index extends AppAction
 
         // ơ֥륹޼
         $conn =& SyL_DB::getConnection();
-        $schema = $conn->getColumns($tablename);
+        $schema =& $conn->getSchema();
+        $table_columns  = $schema->getColumns($tablename);
+        $table_primary  = $schema->getPrimary($tablename);
+        $table_uniques  = $schema->getUniques($tablename);
+        $table_foreigns = $schema->getForeigns($tablename);
         $conn->closeConnection();
 
-        if (count($schema) == 0) {
-            trigger_error("[SyL error] Columns not found ({$tablename})", E_USER_ERROR);
-        }
-
         // -------------------------------------------------
         // ѿ˥å
         // -------------------------------------------------
         $cmd->stdout("  valiables setting..."); ob_flush();
 
-        $primary  = array();
-        $columns  = array();
         $tables   = array();
-        $sorts    = array();
+        $columns  = array();
         $elements = array();
 
         $maintenance_table = 'a';
         $tables[$maintenance_table] = $table_class;
 
         $i = 1;
-        foreach ($schema as $name => $column) {
+        foreach ($table_columns as $name => $column) {
             // ʸ
             $name = strtoupper($name);
-
-            if ($column['primary']) {
-                $primary[] = $name;
-                $sorts[]   = "{$maintenance_table}.{$name}.ASC";
-            }
             // ơ֥
             $columns[$name]  = '';
             // ե
@@ -363,6 +356,22 @@ class Index extends AppAction
             $i++;
         }
 
+        // ʸ
+        $table_primary = array_map('strtoupper', $table_primary);
+        for ($i=0; $i<count($table_uniques); $i++) {
+            $table_uniques[$i] = array_map('strtoupper', $table_uniques[$i]);
+        }
+        foreach (array_keys($table_foreigns) as $key) {
+            $table_foreigns[$key] = array_change_key_case($table_foreigns[$key], CASE_UPPER);
+            $table_foreigns[$key] = array_map('strtoupper', $table_foreigns[$key]);
+        }
+
+        // ȥ
+        $sorts = array();
+        foreach ($table_primary as $name) {
+            $sorts[] = "{$maintenance_table}.{$name}.ASC";
+        }
+
         // ơ֥륯饹Ѵ
         $table_search  = array();
         $table_replace = array();
@@ -377,7 +386,13 @@ class Index extends AppAction
         $table_replace[] = $tablename;
         // 祭
         $table_search[]  = '{TABLE_PRIMARY}';
-        $table_replace[] = var_export($primary, true);
+        $table_replace[] = var_export($table_primary, true);
+        // ե
+        $table_search[]  = '{TABLE_UNIQUES}';
+        $table_replace[] = var_export($table_uniques, true);
+        // 
+        $table_search[]  = '{TABLE_FOREIGNS}';
+        $table_replace[] = var_export($table_foreigns, true);
         // 
         $table_search[]  = '{TABLE_COLUMNS}';
         $table_replace[] = var_export($columns, true);
