@@ -6,9 +6,9 @@
  * @package   {APP_NAME}
  * @author    {author}
  * @copyright {copyright}
- * @version   $Id: action.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   $Id: action.php,v 1.2 2007/08/27 06:00:04 seasonstream Exp $
  */
-class {SYL_CLASS}
+class {SYL_CLASS} extends AppAction
 {
     /**
      * 󥹥ȥ饯
